from setuptools import setup


setup(
    name='waity',
    version='0.2',
    description='wait any condition',
    url='http://github.com/ilyubin/waity',
    download_url='https://github.com/peterldowns/mypackage/archive/0.2.tar.gz',
    author='Igor Lyubin',
    author_email='igor.lyubin@outlook.com',
    license='MIT',
    packages=['waity'],
    install_requires=[],
    tests_require=['pytest'],
    keywords=['wait', 'sleep', 'timeout'],
)
